@@ -16,6 +16,14 @@ ISC_TIME_SECONDS_PRECISION = 10000
 MAX_CHAR_LENGTH = 32767
 BLOB_SEGMENT_SIZE = 32000
 
+DESCRIPTION_NAME = 0
+DESCRIPTION_TYPE_CODE = 1
+DESCRIPTION_DISPLAY_SIZE = 2
+DESCRIPTION_INTERNAL_SIZE = 3
+DESCRIPTION_PRECISION = 4
+DESCRIPTION_SCALE = 5
+DESCRIPTION_NULL_OK = 6
+
 isc_info_end = 1
 isc_info_truncated = 2
 isc_info_error = 3
